
%define prerelease	201310031101

# PAM support
%define _with_pam	1

Summary:	Free implementation of the server-side SMTP protocol as defined by RFC 5321
Name:		opensmtpd
Version:	5.3.3p1
Release:	1%{?prerelease:.%{prerelease}}%{?dist}
License:	ISC
URL:		http://www.opensmtpd.org/
Group:		System Environment/Daemons
Provides:	MTA smtpd smtpdaemon server(smtp)
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root

%if %{prerelease}
Source0:	http://www.opensmtpd.org/archives/%{name}-%{prerelease}p1.tar.gz
%else
Source0:	http://www.opensmtpd.org/archives/%{name}-%{version}.tar.gz
%endif

Source1:	opensmtpd.init
Source2:	opensmtpd.pam

BuildRequires:	db4-devel
BuildRequires:	libevent-devel
BuildRequires:	openssl-devel
BuildRequires:	bison >= 2.4.1
BuildRequires:	automake
BuildRequires:	libtool
%if 0%{?_with_pam}
BuildRequires: pam-devel
%endif
Requires:	/sbin/chkconfig
Requires:	/sbin/service
Requires:	%{_sbindir}/alternatives
Requires(pre):	%{_sbindir}/groupadd
Requires(pre):	%{_sbindir}/useradd

%description
OpenSMTPD is a FREE implementation of the server-side SMTP protocol as defined
by RFC 5321, with some additional standard extensions. It allows ordinary
machines to exchange e-mails with other systems speaking the SMTP protocol.
Started out of dissatisfaction with other implementations, OpenSMTPD nowadays
is a fairly complete SMTP implementation. OpenSMTPD is primarily developed
by Gilles Chehade, Eric Faurot and Charles Longeau; with contributions from
various OpenBSD hackers. OpenSMTPD is part of the OpenBSD Project.
The software is freely usable and re-usable by everyone under an ISC license.

%prep
%setup %{?prerelease: -n %{name}-%{prerelease}p1}

%build
%configure \
    --sysconfdir=%{_sysconfdir}/opensmtpd \
    --libexecdir=%{_libexecdir}/opensmtpd \
    --with-mantype=man \
    %if 0%{?_with_pam}
    --with-pam \
    %endif
    --with-privsep-user=smtpd \
    --with-queue-user=smtpq \
    --with-privsep-path=/var/empty/smtpd \
    --with-sock-dir=/var/run

%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR=%{buildroot}
%{__mkdir_p} -m 0755 %{buildroot}/%{_var}/empty/smtpd
%{__install} -Dm 0755 %SOURCE1 %{buildroot}/%{_initrddir}/smtpd
%if 0%{?_with_pam}
%{__install} -Dm 0644 %SOURCE2  %{buildroot}/%{_sysconfdir}/pam.d/smtp.opensmtpd
%endif
%{__rm} -rf %{buildroot}/%{_bindir}/sendmail
%{__rm} -rf %{buildroot}/%{_sbindir}/mailq
%{__rm} -rf %{buildroot}/%{_sbindir}/newaliases
%{__mv} %{buildroot}/%{_sbindir}/makemap %{buildroot}/%{_sbindir}/makemap.%{name}
%{__ln_s} %{_sbindir}/smtpctl %{buildroot}/%{_sbindir}/sendmail.%{name}
%{__ln_s} %{_sbindir}/smtpctl %{buildroot}/%{_bindir}/mailq.%{name}
%{__ln_s} %{_sbindir}/makemap.%{name} %{buildroot}/%{_bindir}/newaliases.%{name}
%{__mv} %{buildroot}/%{_mandir}/man8/sendmail.8 %{buildroot}/%{_mandir}/man8/sendmail.opensmtpd.8
%{__mv} %{buildroot}/%{_mandir}/man8/makemap.8 %{buildroot}/%{_mandir}/man8/makemap.opensmtpd.8
%{__mv} %{buildroot}/%{_mandir}/man5/aliases.5 %{buildroot}/%{_mandir}/man5/aliases.opensmtpd.5

%pre
getent group smtpd &>/dev/null || %{_sbindir}/groupadd -r smtpd
getent group smtpq &>/dev/null || %{_sbindir}/groupadd -r smtpq
getent passwd smtpd &>/dev/null || \
    %{_sbindir}/useradd -r -g smtpd -s /sbin/nologin -c "opensmtpd privsep user" -d /var/empty/smtpd smtpd
getent passwd smtpq &>/dev/null || \
    %{_sbindir}/useradd -r -g smtpq -s /sbin/nologin -c "opensmtpd queue user" -d /var/empty/smtpd smtpq

%post
/sbin/chkconfig --add smtpd

%{_sbindir}/alternatives --install %{_sbindir}/sendmail mta %{_sbindir}/sendmail.opensmtpd 10 \
	--slave %{_bindir}/mailq mta-mailq %{_bindir}/mailq.opensmtpd \
	--slave /etc/pam.d/smtp mta-pam /etc/pam.d/smtp.opensmtpd \
	--slave %{_bindir}/newaliases mta-newaliases %{_bindir}/newaliases.opensmtpd \
	--slave %{_sbindir}/makemap mta-makemap %{_sbindir}/makemap.opensmtpd \
	--slave /usr/lib/sendmail mta-sendmail %{_sbindir}/sendmail.opensmtpd \
	--slave %{_mandir}/man1/makemap.1.gz mta-makemapman %{_mandir}/man8/makemap.opensmtpd.8.gz \
	--slave %{_mandir}/man1/mailq.1.gz mta-mailqman %{_mandir}/man8/smtpctl.8.gz \
	--slave %{_mandir}/man1/newaliases.1.gz mta-newaliasesman %{_mandir}/man8/newaliases.8.gz \
	--slave %{_mandir}/man5/aliases.5.gz mta-aliasesman %{_mandir}/man5/aliases.opensmtpd.5.gz \
	--slave %{_mandir}/man8/sendmail.8.gz mta-sendmailman %{_mandir}/man8/sendmail.opensmtpd.8.gz \
	--initscript smtpd

echo -e "\n Don't forget to call: /usr/sbin/alternatives --set mta /usr/sbin/sendmail.opensmtpd"
echo -e " if you want to switch to OpenSMTPD MTA immediately.\n"

%preun
if [ $1 = 0 ]; then
	/sbin/service smtpd stop > /dev/null 2>&1
	/sbin/chkconfig --del smtpd
	%{_sbindir}/alternatives --remove mta %{_sbindir}/sendmail.opensmtpd
fi

%postun
if [ "$1" -ge "1" ]; then
	/sbin/service opensmtpd condrestart > /dev/null 2>&1
        mta=`readlink /etc/alternatives/mta`
        if [ "$mta" == "%{_sbindir}/sendmail.opensmtpd" ]; then
                /usr/sbin/alternatives --set mta %{_sbindir}/sendmail.opensmtpd
        fi
fi

echo -e "\n Don't forget to call: /usr/sbin/alternatives --set mta /usr/sbin/sendmail.sendmail"
echo -e " if you want to switch to Sendmail after OpenSMTPD MTA uninstall.\n"

%files
%dir %attr(0711,root,root) %{_var}/empty/smtpd
%config(noreplace) %{_sysconfdir}/%{name}/smtpd.conf
%doc INSTALL LICENSE README.md THANKS
%doc %{_mandir}/man5/*.5.gz
%doc %{_mandir}/man8/*.8.gz
%if 0%{?_with_pam}
%{_sysconfdir}/pam.d/smtp.opensmtpd
%endif
%{_initrddir}/smtpd
%{_libexecdir}/%{name}/*
%{_bindir}/mailq.%{name}
%{_bindir}/newaliases.%{name}
%{_sbindir}/sendmail.%{name}
%{_sbindir}/makemap.%{name}
%{_sbindir}/smtpctl
%{_sbindir}/smtpd

%changelog
* Wed Sep 04 2013 Denis Fateyev <denis@fateyev.com> - 5.3.3p1-1.denf
- Better snapshots support, script cleanup

* Mon Jun 10 2013 Denis Fateyev <denis@fateyev.com> - 5.3.3p1-1.denf
- Initial release
